Learn R Programming

giniVarCI (version 0.0.1-3)

gfrechet: Gini index for the Frechet distribution with user-defined shape parameters

Description

Calculates the Gini indices for the Frechet distribution with shape parameters \(s\).

Usage

gfrechet(shape)

Value

A numeric vector with the Gini indices. A NA is returned when a shape parameter is non-numeric or smaller than 1.

Arguments

shape

A vector of positive real numbers higher or equal than 1 specifying shape parameters \(s\) of the Frechet distribution.

Author

Juan F Munoz jfmunoz@ugr.es

Jose M Pavia pavia@uv.es

Encarnacion Alvarez encarniav@ugr.es

Details

The Frechet distribution with location parameter \(a\), scale parameter \(b\), shape parameter \(s\) and denoted as \(Frechet(a,b,s)\), where \(a>0\), \(b>0\) and \(s>0\), has a probability density function given by (Kleiber and Kotz, 2003; Johnson et al., 1995) $$f(y) = \displaystyle \frac{sb}{(y-a)^{2}} \left(\frac{b}{y-a}\right)^{s-1} \exp\left[- \displaystyle \left(\frac{b}{y-a}\right)^{s} \right],$$ and a cumulative distribution function given by $$F(y)= \displaystyle \exp\left[- \displaystyle \left(\frac{b}{y-a}\right)^{s} \right],$$ where \(y > a\).

The Gini index, for \(s \geq 1\), can be computed as $$G = 2^{1/s} -1.$$

References

Kleiber, C. and Kotz, S. (2003). Statistical Size Distributions in Economics and Actuarial Sciences, Hoboken, NJ, USA: Wiley-Interscience.

Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995) Continuous Univariate Distributions, volume 1, chapter 14. Wiley, New York.

See Also

gdagum, gburr, gfisk, gpareto, ggompertz

Examples

Run this code
# Gini index for the Frechet distribution with a shape parameter 's = 1'.
gfrechet(shape = 1)

# Gini indices for the Frechet distribution and different shape parameters.
gfrechet(shape = 1:10)

Run the code above in your browser using DataLab